.. module:: pymeasure.instruments.keysight

########
Keysight
########

This section contains specific documentation on the keysight instruments that are implemented. If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

If the instrument you are looking for is not here, also check :doc:`Agilent<../agilent/index>` or :doc:`HP<../hp/index>` for older instruments. 

.. toctree::
   :maxdepth: 2

   keysightDSOX1102G
   keysightN5767A
   keysightN7776C
   keysightE36312A
   keysightE3631A